moonshine.models.UNet
=====================

.. currentmodule:: moonshine.models

.. autoclass:: UNet

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~UNet.__init__
      ~UNet.add_module
      ~UNet.apply
      ~UNet.bfloat16
      ~UNet.buffers
      ~UNet.children
      ~UNet.cpu
      ~UNet.cuda
      ~UNet.describe
      ~UNet.double
      ~UNet.eval
      ~UNet.extra_repr
      ~UNet.float
      ~UNet.forward
      ~UNet.get_buffer
      ~UNet.get_extra_state
      ~UNet.get_parameter
      ~UNet.get_submodule
      ~UNet.half
      ~UNet.ipu
      ~UNet.load_state_dict
      ~UNet.load_weights
      ~UNet.modules
      ~UNet.named_buffers
      ~UNet.named_children
      ~UNet.named_modules
      ~UNet.named_parameters
      ~UNet.num_params
      ~UNet.parameters
      ~UNet.register_backward_hook
      ~UNet.register_buffer
      ~UNet.register_forward_hook
      ~UNet.register_forward_pre_hook
      ~UNet.register_full_backward_hook
      ~UNet.register_load_state_dict_post_hook
      ~UNet.register_module
      ~UNet.register_parameter
      ~UNet.requires_grad_
      ~UNet.set_extra_state
      ~UNet.share_memory
      ~UNet.state_dict
      ~UNet.to
      ~UNet.to_empty
      ~UNet.train
      ~UNet.type
      ~UNet.xpu
      ~UNet.zero_grad
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~UNet.T_destination
      ~UNet.dump_patches
      ~UNet.training
   
   